Attribute VB_Name = "modMain"
Option Explicit

Public Const coAdmin = -2
Public Const coNoLogin = -1
Public Const coNewCustomer = -3
Public Const coExistingAccount = -4

Dim cWork As Workspace
Public gdbMain As Database
Public cLogin As clsManageLogin

' common variables
Public DatabaseMode As String
Public DbDSN As String
Public DbUserID As String
Public DbPassword As String
Public PerformanceMode As Boolean
                                          
Public Sub Restore(Optional sCancel As String = "Yes")
    
        
    ' Delete data in the CUSTOMERS, ORDERS, & PRODUCTS tables. Insert data from the
    ' backup tables into these tables.
    
    gdbMain.Execute "DELETE CUSTOMERS.* FROM CUSTOMERS;"
    gdbMain.Execute "INSERT INTO CUSTOMERS SELECT CUSTOMERSbak.* FROM CUSTOMERSbak;"
    gdbMain.Execute "DELETE ORDERS.* FROM ORDERS;"
    gdbMain.Execute "INSERT INTO ORDERS SELECT ORDERSbak.* FROM ORDERSbak;"
    gdbMain.Execute "DELETE PRODUCTS.* FROM PRODUCTS;"
    gdbMain.Execute "INSERT INTO PRODUCTS SELECT PRODUCTSbak.* FROM PRODUCTSbak;"
    
    Exit Sub

RestoreErr:
    MsgBox Prompt:=Err.Number & ": " & Err.Description, Title:="Unexpected error in modMain.Restore"

End Sub ' Restore

Sub AppClose()
    Dim frm As Object
        
    For Each frm In Forms
        Unload frm
    Next
End Sub

Sub Main()
    Dim cPath As String
    Dim cConnect As String
    Dim timerHolder As Long
    Dim rsCustomers As Recordset
    
    Screen.MousePointer = vbHourglass
    
    ' PeformanceBuild is a conditional compilation variable that determines whether Classics
    ' will run in regular mode or in Performance mode.  Perf is for making PerformanceStudio
    ' recordings.  PerformanceMode is the variable that is referenced throughout the application
    ' when Performance specific behavior is needed.  (example:  treeview is not pre-populated
    ' in PerformanceMode.)
    
    #If PerformanceBuild = 1 Then
        PerformanceMode = True
        GetDBInfo
    #Else
        PerformanceMode = False
        DatabaseMode = "Access"
    #End If
    
    If PerformanceMode = False Then
        timerHolder = Timer
        frmSplash.Show
        frmSplash.Refresh
    End If
    
    ' cLogin is an instance of the class that holds logon information
    Set cLogin = New clsManageLogin
    
    ' connect to appropriate database.  DatabaseMode is set in GetDbInfo
    On Error GoTo DataError
    Select Case DatabaseMode
    Case "Access"
        Set cWork = CreateWorkspace("", DbUserID, DbPassword, dbUseODBC)
        Set gdbMain = cWork.OpenDatabase("ClassicsAccess", dbDriverComplete, False, "ODBC;")
        Restore     'Restores database from backup tables in MDB
'       BB 03.31.99: Removed hard coded MDB path.  Changed to reference ODBC
'       cPath = App.Path + "\classicsdata.mdb"
'       Set gdbMain = OpenDatabase(cPath, , False, cConnect)

    Case "SQL Server 6.5"
        'BB: 04.01.99 Added SQL Server Functionality
        Set cWork = CreateWorkspace("", DbUserID, DbPassword, dbUseODBC)
        Set gdbMain = cWork.OpenDatabase(DbDSN, dbDriverComplete, False, "ODBC;")
    Case "Oracle 7.3"
        Set cWork = CreateWorkspace("", DbUserID, DbPassword, dbUseODBC)
        Set gdbMain = cWork.OpenDatabase(DbDSN, dbDriverComplete, False, "ODBC;")
    End Select
    On Error GoTo 0
    
    Load frmMain
    
    If PerformanceMode = False Then
        ' leave the splash screen up for at least one second
        Do Until Int(Timer) > timerHolder
        Loop
        frmSplash.Hide
    End If
            
    Screen.MousePointer = vbDefault
    
    frmExistingLogin.Show vbModal
            
    frmMain.Show
    frmMain.Refresh
    
    frmMain.statusMain.SimpleText = DatabaseMode + " mode"
        
    
    Screen.MousePointer = vbDefault
    
    Exit Sub

DataError:
Screen.MousePointer = vbDefault
If PerformanceMode = False Then
    MsgBox Err.Description & ".  Make sure that you've created a System ODBC DSN called ClassicsAccess pointing to the ClassicsData.mdb database.  See the installation section of the ATBU Seminar Guide for more information.", vbOKOnly, "Database Problem!"
Else
    MsgBox Err.Description & ".  Check your Oracle or SQL Server configuration.  See the installation section of the ATBU Seminar Guide for more information.", vbOKOnly, "Database Problem!"
End If
AppClose
End Sub

Sub GetDBInfo()
    Dim i As Integer
    Dim datLine As Byte
    Dim nl As String
    
    i = FreeFile
    On Error GoTo CreateDat:
    ' open db config file.  if does not exist, create new file
    Open App.Path + "\dbconfig.dat" For Input As #i
    
    ' populate DBname, dsnname, userid, and password with first four uncommented lines in dbconfig.dat
    Do Until EOF(i) = True
        Line Input #i, nl
        nl = Trim(nl)
        If nl <> "(none)" And Left(nl, 1) <> "#" And Len(nl) > 0 Then ' is some data
            datLine = datLine + 1
            Select Case datLine
            Case 1 ' db name
                DatabaseMode = nl
            Case 2 ' dsn name
                DbDSN = nl
            Case 3 ' userid
                DbUserID = nl
            Case 4 ' password
                DbPassword = nl
            End Select
        End If
    Loop
    
    Exit Sub
    
CreateDat:
MsgBox "Warning! 'dbconfig.dat' not found in application directory.  A new 'dbconfig.dat' will be created.  To customize your data access, edit this file with a text editor.  You will need to restart Classics."
Open App.Path + "\dbconfig.dat" For Output As #i
Print #i, "# Classics Online Database Configuration File"
Print #i, "# Note:  You can edit this file to customize your data access."
Print #i, "# Classics will use the first four uncommented lines to set Database Name, DSN Name, UserID, and Password."
Print #i, "# (none) translates to a blank entry"
Print #i,
Print #i, "# Oracle 7.3 Configuration"
Print #i, "Oracle 7.3"
Print #i, "ClassicsOracle"
Print #i, "oracle"
Print #i, "oracle"
Print #i,
Print #i, "# MS SQL Server 6.5 Configuration"
Print #i, "#MS SQL Server 6.5"
Print #i, "#ClassicsMSSQL"
Print #i, "#admin"
Print #i, "#(none)"
Close i
End

End Sub

